==> ba-react-fetch-list-api-0.0.2.tgz: package/FetchListAPI/index.js <==
// @flow
import _ from 'lodash';
import {compose, defaultProps, lifecycle, mapProps, withHandlers} from 'recompose';
import {connect} from 'react-redux';
import {default as reducers} from './reducers';
import {default as rest} from './rest';
export {reducers, rest};

const
	getCounter = (params: {
		counter: string,
		key: string,
		state: Object,
	}) => _.toNumber(
		_.get(params.state, `fetchApi.${params.key}.lastResponse.headers.${params.counter}`, 0)
	);

export default (propsMixin: {
	baseURL?: string,
	entity: 'contacts',
	fetchParams: (props: Object) => Object,
	filtersState: string,
	key: 'contacts',
	pageState: string,
	paramsChangeCallback?: () => void,
	sortingState: string,
}) => (WrappedComponent: any) => compose(
	defaultProps({flaFetched: {}}),

	connect(
		(state, props) => ({
			flaFetched: {
				...props.flaFetched,

				[propsMixin.key]: {
					baseURL   : propsMixin.baseURL || 'http://local.api.app.bluavenu.com:8000',
					data      : state.fetchApi[propsMixin.key].data,
					filters   : _.get(state, propsMixin.filtersState),
					loading   : state.fetchApi[propsMixin.key].loading,
					page      : _.get(state, propsMixin.pageState),
					pagesCount: getCounter({counter: 'pages-count', key: propsMixin.key, state}),
					sorting   : _.get(state, propsMixin.sortingState),
					totalCount: getCounter({counter: 'total-count', key: propsMixin.key, state}),
				},
			},
		}),

		dispatch => ({dispatch}),
	),

	mapProps(props => ({
		...props,

		flaFetched: {
			...props.flaFetched,

			[propsMixin.key]: {
				...props.flaFetched[propsMixin.key],

				// Let connect() to be called and fill up props before fetchParams() called being passed with props
				fetchParams: propsMixin.fetchParams(props),

				// There is no way to put .sync into .flaFetched within connect()
				sync: ({
					contacts: (params: {}, callback?: () => void) => props.dispatch(
						rest({
							baseURL: props.baseURL,
							entity : 'contacts',
							key    : 'contacts',
						}).actions.contacts.sync(params, callback)
					),
				})[propsMixin.entity],
			},
		},
	})),

	withHandlers({

		// GET params
		getRequestParams: props => nextProps => {
			const

				/* eslint-disable sort-vars */
				activeProps = (nextProps || props).flaFetched[propsMixin.key],

				filters = _.fromPairs(activeProps.filters.map(
					F => ([_.compact([F.field, F.operator]).join('-'), F.compiledValue || F.value])
				)),

				/* eslint-enable sort-vars */
				request = {filterParams: '', page: activeProps.page, sort: ''},
				sorting = _.get(activeProps, 'sorting.column');

			if(filters)
				request.filterParams = JSON.stringify(filters);

			if(sorting)
				request.sort = JSON.stringify({[sorting]: _.get(activeProps, 'sorting.order') === 'asc' ? 1 : -1});

			return _.extend(request, activeProps.fetchParams);
		},
	}),

	lifecycle({
		componentDidMount() {
			if(propsMixin.fetchOnMount)
				this.props.flaFetched[propsMixin.key].sync(this.props.getRequestParams());
		},

		componentWillReceiveProps(nextProps) {
			const

				// WARN Probably _.isEqual will cause performance issues, go for immutability!
				isFilterChanged = !_.isEqual(
					nextProps.flaFetched[propsMixin.key].filters,
					this.props.flaFetched[propsMixin.key].filters,
				),

				// WARN isPageChanged must be false if page changed from undefined to 1
				isPageChanged = this.props.flaFetched[propsMixin.key].page !== nextProps.flaFetched[propsMixin.key].page,

				isSearchChanged = !_.isEqual(
					nextProps.flaFetched[propsMixin.key].fetchParams,
					this.props.flaFetched[propsMixin.key].fetchParams
				),

				isSortingChanged = !_.isEqual(
					nextProps.flaFetched[propsMixin.key].sorting,
					this.props.flaFetched[propsMixin.key].sorting,
				);

			if(isFilterChanged || isSortingChanged || isPageChanged || isSearchChanged)
				this.props.flaFetched[propsMixin.key].sync(
					nextProps.getRequestParams(nextProps),

					// If fetch params changed — call params change callback, ignore page changes
					() => propsMixin.paramsChangeCallback &&
						(isFilterChanged || isSortingChanged || isSearchChanged) &&
						!isPageChanged &&
						propsMixin.paramsChangeCallback(this.props.dispatch),
				);
		},
	}),
)(WrappedComponent);

==> ba-react-fetch-list-api-0.0.7.tgz: package/FetchListAPI/index.js <==
// @flow
import _ from 'lodash';
import {compose, defaultProps, lifecycle, mapProps, withHandlers} from 'recompose';
import {connect} from 'react-redux';
import {default as reducers} from './reducers';
import {default as rest} from './rest';
export {reducers, rest};

const
	getCounter = (params: {
		counter: string,
		key: string,
		state: Object,
	}) => _.toNumber(
		_.get(params.state, `fetchApi.${params.key}.lastResponse.headers.${params.counter}`, 0)
	);

export default (propsMixin: {
	baseURL?: string,
	entity: 'contacts',
	fetchParams: (props: Object) => Object,
	filtersState: string,
	key: 'contacts',
	pageState: string,
	paramsChangeCallback?: () => void,
	sortingState: string,
}) => (WrappedComponent: any) => compose(
	defaultProps({flaFetched: {}}),

	connect(
		(state, props) => ({
			flaFetched: {
				...props.flaFetched,

				[propsMixin.key]: {
					baseURL   : propsMixin.baseURL || 'http://local.api.app.bluavenu.com:8000',
					data      : state.fetchApi[propsMixin.key].data,
					filters   : _.get(state, propsMixin.filtersState),
					loading   : state.fetchApi[propsMixin.key].loading,
					page      : _.get(state, propsMixin.pageState),
					pagesCount: getCounter({counter: 'pages-count', key: propsMixin.key, state}),
					sorting   : _.get(state, propsMixin.sortingState),
					totalCount: getCounter({counter: 'total-count', key: propsMixin.key, state}),
				},
			},
		}),

		dispatch => ({dispatch}),
	),

	mapProps(props => ({
		...props,

		flaFetched: {
			...props.flaFetched,

			[propsMixin.key]: {
				...props.flaFetched[propsMixin.key],

				// Let connect() to be called and fill up props before fetchParams() called being passed with props
				fetchParams: propsMixin.fetchParams(props),

				// There is no way to put .sync into .flaFetched within connect()
				sync: ({
					contacts: (params: {}, callback?: () => void) => props.dispatch(
						rest({
							baseURL: props.flaFetched[propsMixin.key].baseURL,
							entity : 'contacts',
							key    : 'contacts',
						}).actions.contacts.sync(params, callback)
					),
				})[propsMixin.entity],
			},
		},
	})),

	withHandlers({

		// GET params
		getRequestParams: props => nextProps => {
			const

				/* eslint-disable sort-vars */
				activeProps = (nextProps || props).flaFetched[propsMixin.key],

				filters = _.fromPairs(activeProps.filters.map(
					F => ([_.compact([F.field, F.operator]).join('-'), F.compiledValue || F.value])
				)),

				/* eslint-enable sort-vars */
				request = {filterParams: '', page: activeProps.page, sort: ''},
				sorting = _.get(activeProps, 'sorting.column');

			if(filters)
				request.filterParams = JSON.stringify(filters);

			if(sorting)
				request.sort = JSON.stringify({[sorting]: _.get(activeProps, 'sorting.order') === 'asc' ? 1 : -1});

			return _.extend(request, activeProps.fetchParams);
		},
	}),

	lifecycle({
		componentDidMount() {
			if(propsMixin.fetchOnMount)
				this.props.flaFetched[propsMixin.key].sync(this.props.getRequestParams());
		},

		componentWillReceiveProps(nextProps) {
			const

				// WARN Probably _.isEqual will cause performance issues, go for immutability!
				isFilterChanged = !_.isEqual(
					nextProps.flaFetched[propsMixin.key].filters,
					this.props.flaFetched[propsMixin.key].filters,
				),

				// WARN isPageChanged must be false if page changed from undefined to 1
				isPageChanged = this.props.flaFetched[propsMixin.key].page !== nextProps.flaFetched[propsMixin.key].page,

				isSearchChanged = !_.isEqual(
					nextProps.flaFetched[propsMixin.key].fetchParams,
					this.props.flaFetched[propsMixin.key].fetchParams
				),

				isSortingChanged = !_.isEqual(
					nextProps.flaFetched[propsMixin.key].sorting,
					this.props.flaFetched[propsMixin.key].sorting,
				);

			if(isFilterChanged || isSortingChanged || isPageChanged || isSearchChanged)
				this.props.flaFetched[propsMixin.key].sync(
					nextProps.getRequestParams(nextProps),

					// If fetch params changed — call params change callback, ignore page changes
					() => propsMixin.paramsChangeCallback &&
						(isFilterChanged || isSortingChanged || isSearchChanged) &&
						!isPageChanged &&
						propsMixin.paramsChangeCallback(this.props.dispatch),
				);
		},
	}),
)(WrappedComponent);
